# Frequently Asked Questions

(what-is-si)=
## What is Simulation Intelligence?

Simulation Intelligence (SI) is a paradigm to bring advances in AI, computing, and simulation together to enable the next generation of intelligent systems (see [Lavin et al., 2021](https://arxiv.org/abs/2112.03235)). Simulation Intelligence combines *motifs* from several different fields of research, including:

> (1) Multi-physics and multi-scale modeling; (2) Surrogate modeling and emulation; (3) Simulation-based inference; (4) Causal modeling and inference; (5) Agent-based modeling; (6) Probabilistic programming; (7) Differentiable programming; (8) Open-ended optimization; (9) Machine programming.
> - [Lavin et al., 2021](https://arxiv.org/abs/2112.03235)

Tesseracts are a key building block of Simulation Intelligence, enabling the composition of complex, multi-physics, and multi-scale models into a single, differentiable function.
